@@ -625,10 +625,11 @@ def savediv_(*args):
     denominator = parseExpression(args[1])
     onzero = None if len(args) ==2 else parseExpression(args[2])
 
-    if onzero:
+    if onzero is not None:
         return "( "+ str(onzero) + ")" + ' if (' + str(denominator) + ') == 0 else (' + str(nominator) + ' / ' + str(denominator) + ")"
     else:
-        return '(' + str(nominator) + ' / ' + str(denominator) + ")"
+        return "(0)" + ' if (' + str(denominator) + ') == 0 else (' + str(nominator) + ' / ' + str(
+            denominator) + ")"
 
 def history_(*args):
     args = remove_nesting(args)
